@@ -6,24 +6,6 @@ import scipy.ndimage
 import numpy as np
 
 
-class Observable(object):
-    def __init__(self):
-        self.uid = 0
-        self.listeners = []
-
-    def subscribe(self, listener):
-        self.uid += 1
-        self.listeners.append(listener)
-        return partial(self.unsubscribe, int(self.uid))
-
-    def unsubscribe(self, uid):
-        del self.listeners[uid]
-
-    def announce(self, *args):
-        for listener in self.listeners:
-            listener(*args)
-
-
 def timeout_cache(interval):
     def decorator(f):
         cache = {}
