@@ -1,4 +1,5 @@
 import datetime as dt
+import numpy as np
 import glob
 from forest import earth_networks
 
@@ -18,7 +19,12 @@ def test_earth_networks(tmpdir):
     frame = loader.load_date(dt.datetime(2019, 4, 17))
     result = frame.iloc[0]
     atol = 0.000001
-    assert result["date"] == dt.datetime(2019, 4, 17, 0, 0, 1, 440000)
-    assert result["flash_type"] == "IC" 
+    if isinstance(result["date"], dt.datetime):
+        # Pandas <0.25.x
+        assert result["date"] == dt.datetime(2019, 4, 17, 0, 0, 1, 440000)
+    else:
+        # Pandas 1.0.x
+        assert result["date"] == np.datetime64('2019-04-17T00:00:01.440000000')
+    assert result["flash_type"] == "IC"
     assert abs(result["latitude"] - 2.75144) < atol
     assert abs(result["longitude"] - 31.92064) < atol
